@@ -21,6 +21,8 @@ from ubik.view import TablePrinter
 from ubik.tools import confirm
 from ubik.tools import clean
 
+from ubik.status import status
+
 from ubik.exceptions import *
 
 class Cli(object):
@@ -55,33 +57,33 @@ class Cli(object):
         # update          #
         ###################
         elif self.args.get('update', False):
-            stream_logger.info(' :: Update')
+            stream_logger.info('=> Update')
             try:
                 db.sync()
             except Exception as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
         ###################
         # clean           #
         ###################
         elif self.args.get('clean', False):
-            stream_logger.info(' :: Clean')
+            stream_logger.info('=> Cleaning')
             clean()
         ###################
         # reinstall       #
         ###################
         elif self.args.get('reinstall', False):
             # Sync Database
-            stream_logger.info(' :: Update')
+            stream_logger.info('=> Updating')
             try:
                 db.sync()
             except Exception as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
             # Create installer
-            stream_logger.info(' :: Resolving')
+            stream_logger.info('=> Resolving')
             reinstaller = Reinstaller()
             if not isinstance(self.args['<package>'], list):
                 packages = [self.args['<package>']]
@@ -95,30 +97,30 @@ class Cli(object):
                             reinstaller.resolve(package)
                             reinstaller.feed(reinstaller.resolved)
                         except RuntimeError as err:
-                            if conf.get('logger','level') >= 2:
+                            if int(conf.get('logger','level')) >= 2:
                                 traceback.print_exc(file=sys.stdout)
-                            stream_logger.info(' :: Dependencies resolve failed (%s)' % err)
+                            stream_logger.info('!! Dependencies resolve failed (%s)' % err)
                             sys.exit(1)
                 else:
                     reinstaller.feed(db.get(packages))
             except DatabaseException as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
 
             if not reinstaller.packages:
-                stream_logger.info(' :: No package(s) to reinstall')
+                stream_logger.info('=> No package(s) to reinstall')
                 sys.exit(0)
-            stream_logger.info(' :: Following packages will be reinstalled:')
+            stream_logger.info('=> Following packages will be reinstalled:')
             for package in reinstaller.packages:
-                stream_logger.info('    - %s' % package.name)
+                stream_logger.info('   - %s' % package.name)
             if not self.args.get('--force-yes', False):
                 if confirm():
                     reinstaller.download()
                     try:
                         reinstaller.reinstall(ignore_errors=self.args.get('--ignore-errors', False))
                     except Exception as err:
-                        if conf.get('logger','level') >= 2:
+                        if int(conf.get('logger','level')) >= 2:
                             traceback.print_exc(file=sys.stdout)
                         raise
                 else:
@@ -129,7 +131,7 @@ class Cli(object):
                 try:
                     reinstaller.reinstall(ignore_errors=self.args.get('--ignore-errors', False))
                 except Exception as err:
-                    if conf.get('logger','level') >= 2:
+                    if int(conf.get('logger','level')) >= 2:
                         traceback.print_exc(file=sys.stdout)
                     raise
 
@@ -138,17 +140,17 @@ class Cli(object):
         ###################
         elif self.args.get('install', False):
             # Sync Database
-            stream_logger.info(' :: Update')
+            stream_logger.info('=> Updating')
             try:
                 db.sync()
             except Exception as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
             # Create installer
             installer = Installer()
             # Resolve deps
-            stream_logger.info(' :: Resolving dependencies')
+            stream_logger.info('=> Resolving dependencies')
             if not isinstance(self.args['<package>'], list):
                 packages = [self.args['<package>']]
             else:
@@ -160,21 +162,21 @@ class Cli(object):
                         installer.resolve(package)
                         installer.feed(installer.resolved)
                     except RuntimeError as err:
-                        if conf.get('logger','level') >= 2:
+                        if int(conf.get('logger','level')) >= 2:
                             traceback.print_exc(file=sys.stdout)
-                        stream_logger.info(' :: Dependencies resolve failed (%s)' % err)
+                        stream_logger.info('!! Dependencies resolve failed (%s)' % err)
                         sys.exit(1)
             except DatabaseException as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
 
             if not installer.packages:
-                stream_logger.info('    - No package(s) found')
+                stream_logger.info('   - No package(s) found')
                 sys.exit(1)
-            stream_logger.info(' :: Following dependencies will be installed:')
+            stream_logger.info('=> Following dependencies will be installed:')
             for dep in installer.packages:
-                stream_logger.info('    - %s' % dep.name)
+                stream_logger.info('   - %s' % dep.name)
 
             if not self.args.get('--force-yes', False):
                 if confirm():
@@ -182,7 +184,7 @@ class Cli(object):
                     try:
                         installer.install(ignore_errors=self.args.get('--ignore-errors', False))
                     except Exception as err:
-                        if conf.get('logger','level') >= 2:
+                        if int(conf.get('logger','level')) >= 2:
                             traceback.print_exc(file=sys.stdout)
                         raise
                 else:
@@ -193,7 +195,7 @@ class Cli(object):
                 try:
                     installer.install(ignore_errors=self.args.get('--ignore-errors', False))
                 except Exception as err:
-                    if conf.get('logger','level') >= 2:
+                    if int(conf.get('logger','level')) >= 2:
                         traceback.print_exc(file=sys.stdout)
                     raise
         ###################
@@ -201,16 +203,16 @@ class Cli(object):
         ###################
         elif self.args.get('upgrade', False):
             # Sync Database
-            stream_logger.info(' :: Update')
+            stream_logger.info('=> Updating')
             try:
                 db.sync()
             except Exception as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
             # Create Upgrader
             upgrader = Upgrader()
-            stream_logger.info(' :: Resolving')
+            stream_logger.info('=> Resolving')
             if not isinstance(self.args['<package>'], list):
                 packages = [self.args['<package>']]
             else:
@@ -222,12 +224,12 @@ class Cli(object):
                 upgrader.feed(packages)
 
             if not upgrader.packages:
-                stream_logger.info(' :: No package(s) to upgrade')
+                stream_logger.info('!! No package(s) to upgrade')
                 sys.exit(0)
 
-            stream_logger.info(' :: Following packages will be upgraded:')
+            stream_logger.info('=> Following packages will be upgraded:')
             for package in upgrader.packages:
-                stream_logger.info('    - %s' % package.name)
+                stream_logger.info('   - %s' % package.name)
 
             if not self.args.get('--force-yes', False):
                 if confirm():
@@ -235,7 +237,7 @@ class Cli(object):
                     try:
                         upgrader.upgrade(ignore_errors=self.args.get('--ignore-errors', False))
                     except Exception as err:
-                        if conf.get('logger','level') >= 2:
+                        if int(conf.get('logger','level')) >= 2:
                             traceback.print_exc(file=sys.stdout)
                         raise
                 else:
@@ -246,7 +248,7 @@ class Cli(object):
                 try:
                     upgrader.upgrade(ignore_errors=self.args.get('--ignore-errors', False))
                 except Exception as err:
-                    if conf.get('logger','level') >= 2:
+                    if int(conf.get('logger','level')) >= 2:
                         traceback.print_exc(file=sys.stdout)
                     raise
         ###################
@@ -255,22 +257,21 @@ class Cli(object):
         elif self.args.get('remove', False):
             # Create remover
             remover = Remover()
-            stream_logger.info(' :: Resolving')
             packages = db.get(self.args.get('<package>'))
 
             try:
                 remover.feed(packages)
             except DatabaseException as err:
-                if conf.get('logger','level') >= 2:
+                if int(conf.get('logger','level')) >= 2:
                     traceback.print_exc(file=sys.stdout)
                 self.error_link()
 
             if not remover.packages:
                 sys.exit(0)
 
-            stream_logger.info(' :: Following packages will be removed:')
+            stream_logger.info('=> Following packages will be removed:')
             for package in remover.packages:
-                stream_logger.info('    - %s' % package.name)
+                stream_logger.info('   - %s' % package.name)
 
             if not self.args.get('--force-yes', False):
                 if confirm():
@@ -282,6 +283,31 @@ class Cli(object):
                 try:
                     remover.remove(ignore_errors=self.args.get('--ignore-errors', False))
                 except Exception as err:
-                    if conf.get('logger','level') >= 2:
+                    if int(conf.get('logger','level')) >= 2:
                         traceback.print_exc(file=sys.stdout)
                         raise
+        ##########
+        # search #
+        ##########
+        elif self.args.get('search', False):
+            packages = db.get(self.args.get('<package>'))
+            if not packages:
+                stream_logger.info('!! No package found')
+                sys.exit(1)
+            for package in packages:
+                stream_logger.info('Name: %s' % package.name)
+                if package in db.get_installed():
+                    stream_logger.info('Version: %s-%s' % (package.version, package.release))
+                    stream_logger.info('Status: %s' % status[package.status])
+                else:
+                    stream_logger.info('Version: %s-%s' % (package.repo_version, package.repo_release))
+                    stream_logger.info('Status: %s' % status[package.status])
+
+                stream_logger.info('Requires: %s' % ','.join(package.requires))
+                stream_logger.info('Description: %s' % package.description)
+                stream_logger.info('Architecture: %s' % package.arch)
+                stream_logger.info('Distribution: %s' % package.dist)
+                stream_logger.info('Distribution version: %s' % package.vers)
+                if package is not packages[-1]:
+                    stream_logger.info('')
+            sys.exit(0)
